@@ -1,5 +1,6 @@
 '''
 Useful math utilities.
+数学公式库
 '''
 import numpy as np
 
@@ -24,6 +25,9 @@ def log_softmax(x, t=1.0, axis=-1):
     return x_ - x_max - np.log(exp_sum)
 
 def sigmoid(x):
+    '''
+    sigmoid函数
+    '''
     x = np.asarray(x)
     ret = np.zeros_like(x, dtype=float)
     ret[x > 0] = 1.0 / (1.0 + np.exp(-x[x > 0]))
@@ -31,6 +35,8 @@ def sigmoid(x):
     ret[x <= 0] = a/(1.0 + a)
     return ret
 
+def gelu(x):
+    pass
 
 
 
